
function [pts,err]=decoding_points(pts_compressed,patterns)

M=sum(patterns);
deg=(-3+sqrt(1+8*M))/2; % M=(deg+1)*(deg+2)/2.

L=length(patterns);

% WORKING WITH COLUMN VECTORS.
if size(patterns,2) > size(patterns,1)
    patterns=patterns';
end

if size(pts_compressed,2) > size(pts_compressed,1)
    pts_compressed=pts_compressed';
end

% COMPUTING POINTS.

err=0;

if rem(deg,2) == 0

    % IN THIS CASE, THE INITIAL RADIUS IS BY DEFAULT "0" AND THE FINAL
    % RADIUS IS "1". SO, IF "L" IS THE NUMBER OF DISKS, ONE NEEDS "L-1"
    % INITIAL ANGLES AND "L-2" RADII. CONSEQUENTLY THE LENGTH OF THE VECTOR
    % pts_compressed IS "2*L-3".

    % THE FIRST "L" COMPONENTS ARE ANGLES, THE OTHER COMPONENTS ARE RADII.
    theta=[0; pts_compressed(1:L-1,1)];
    radii=[0; pts_compressed(L:end,1); 1];

else

    % IN THIS CASE, THE FINAL RADIUS IS "1". SO, IF "L" IS THE NUMBER OF 
    % DISKS, ONE NEEDS "L" INITIAL ANGLES AND "L-1" RADII. CONSEQUENTLY 
    % THE LENGTH OF THE VECTOR pts_compressed IS "2*L-3".

    % THE FIRST "L" COMPONENTS ARE ANGLES, THE OTHER COMPONENTS ARE RADII.
    theta=[pts_compressed(1:L,1)];
    radii=[pts_compressed(L+1:end,1); 1];

end

% SET ERROR IF THE radii ARE NOT AN INCREASING SEQUENCE OR NOT IN [0,1].
if sum(diff(radii) < 0) > 0
    err=1;
    fprintf('\n \t %% WARNING: RADIUS SEQUENCE NOT INCREASING.');
end

if sum(radii < 0) > 0
    err=1;
    fprintf('\n \t %% WARNING: NEGATIVE RADIUS.');
end

if sum(radii > 1) > 0
    err=1;
    fprintf('\n \t %% WARNING: RADIUS BIGGER THAN 1.'); 
end

pts=[];
  
for ii=1:L
    init_angle=theta(ii);
    d=patterns(ii);
    r=radii(ii);
    angles=init_angle+(0:(d-1))'*2*pi/d;
    pts_loc=r*[cos(angles) sin(angles)];
    pts=[pts; pts_loc];
end

