
%--------------------------------------------------------------------------
%% Copyright (C) 2010
%% Matteo Briani, Alvise Sommariva, Marco Vianello.
%%
%% This program is free software; you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation; either version 2 of the License, or
%% (at your option) any later version.
%%
%% This program is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with this program; if not, write to the Free Software
%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
%%
%% Author:
%%          Matteo Briani
%%          Alvise Sommariva  <alvise@math.unipd.it>
%%          Marco Vianello    <marcov@math.unipd.it>
%%
%% Date: December 23, 2010.
%--------------------------------------------------------------------------

clear all;

degv=3:12;           % deg: WAM DEGREE.
extraction_method=1; % extraction_method: 1: QR 2:LU.

family_type=1; % 1: FEKETE 2: LEBESGUE.

starting_point=1;

mildness_vector=[5:8];
method_type_vett=4; % 4: fminsearch.


do_plots=0;

%--------------------------------------------------------------------------
%               ...... HERE THE MAIN PROGRAM BEGINS ......
%--------------------------------------------------------------------------

s='set_disk_leb'; % PUT THE NAME OF YOUR FUNCTION HERE (WITHOUT .m EXTENSION).
diaryname=cat(2,'diary_II_',date,'_',s,'.m');

diary on; diary(diaryname);

fprintf('\n \t ');
uu=cat(2,'function [pts,t]=',s,'(deg)');
fprintf(uu);

fprintf('\n \t switch deg');

for kk=1:length(degv)

    deg=degv(kk);

    %--------------
    % INITIAL SET.
    %--------------

    switch starting_point
        case 0
            if family_type == 1
                % x_start=set_parms_fek(deg);
            else
                % x_start=set_parms_leb(deg);
            end
        otherwise
            x_start=[];

    end

    % INITIAL POINT SET AND ITS STATISTICS TO BE IMPROVED.
    x_in=x_start; patts=disk_patterns(deg);
    if length(x_in) > 0
        
        [pts_in,err]=decoding_points(x_in,patts)
        [lebs,dets,conds]=do_stats(deg,pts_in,[],0);
        if family_type == 1
            value_new=abs(dets); value_old=abs(dets)/2; value_init=value_new;
        else
            value_new=abs(lebs); value_old=2*abs(lebs); value_init=value_new;
        end

    else

        if family_type == 1
            value_new=eps; value_old=value_new/2; value_init=value_new;
        else
            value_new=realmax/2; value_old=2*value_new; value_init=value_new;
        end


    end

    cputiming1=cputime;
    % OPTIMIZATION PROCESS.
    Nits=200;
    for jj=1:Nits

        if abs(value_new - value_old) > 10^(-4)*abs(value_old)

            value_old=abs(value_new);
            [pts_out,x_out,value_new]=parm_iterative_step(deg,x_in,...
                family_type,value_new,mildness_vector,method_type_vett,patts);
            value_new=abs(value_new);
            pts_in=pts_out; x_in=x_out;
            jj_last=jj;
            fprintf('\n \t %% IT: %3.0f OLD: %2.5e NEW: %2.5e',jj,...
                value_old,value_new);

        end



    end

    if jj_last < Nits
        fprintf('\n \n \n \t %% [STABLE CONFIGURATION]: %3.0f',jj_last);
    end

    if family_type == 1
        if abs(value_new) > abs(value_init)
            fprintf('\n \t %% [+]: OLD: %2.5e NEW: %2.5e',abs(value_init),...
                abs(value_new));
        else
            fprintf('\n \n \n \t %% [=]: OLD: %2.5e NEW: %2.5e',abs(value_init),...
                abs(value_new));
        end
    else
        if abs(value_new) < abs(value_init)
            fprintf('\n \n \n \t %% [+]: OLD: %2.5e NEW: %2.5e',abs(value_init),...
                abs(value_new));
        else
            fprintf('\n \n \n \t %% [=]: OLD: %2.5e NEW: %2.5e',abs(value_init),...
                abs(value_new));
        end
    end


    cputiming2=cputime;

    %-------
    % STATS.
    %-------

    timing=cputiming2-cputiming1;
    [lebs,dets,conds]=do_stats(deg,pts_out,timing,1,x_out);


    %-------
    % PLOTS.
    %-------
    if do_plots == 1
        degrees=linspace(0,2*pi,1000); degrees=degrees';
        pts_bnd=[cos(degrees) sin(degrees)];
        plot(pts_bnd(:,1),pts_bnd(:,2),'b-',...
            pts_out(:,1),pts_out(:,2),'r+');
    end

end
