
function [lebs,dets,conds,err]=do_stats(deg,pts,timing,print_stats,t)

if nargin < 3
    timing=0;
end

if nargin < 4
    print_stats=1;
end

if nargin < 5
    t=[];
end

%-------------------------------------------------
% CHECKING IF THE POINTS ARE IN THE UNIT DISK.
% SOME MINIMAL CORRECTIONS.
%-------------------------------------------------

err=0;

if print_stats == 1
    fprintf('\n \n \t case %2.0f ',deg);
end
x=pts(:,1); y=pts(:,2);

s = (x.^2 + y.^2 - 1 > 0);

sum_s=sum(s);

if sum_s == 0
    if print_stats == 1
        fprintf('\n \n \t %% PASSED (I).');
    end
else

    aa=find(x.^2 + y.^2 - 1>0);

    for ss=1:length(aa)
        kk=aa(ss);
        xloc=x(kk); yloc=y(kk);
        if xloc^2+yloc^2 > 1+10^(-13)
            if print_stats == 1
                fprintf('\n \t %% SEVERE CORRECTION: %5.0f',index)
            end
        end

        x(kk)=sqrt(xloc^2/(xloc^2+yloc^2));
        y(kk)=sqrt(yloc^2/(xloc^2+yloc^2));
    end

    s = (x.^2 + y.^2 - 1 > 0) ;
    sum_s=sum(s);
    if sum_s == 0
        if print_stats == 1
            fprintf('\n \n \t %% PASSED (II).');
        end
    else
        if print_stats == 1
            fprintf('\n \n \t %% NOT PASSED.');
            err=1;
        end
    end

            

end

pts_ok=[x y];

%---------------------------
% COMPUTING BASIC CONSTANTS.
%---------------------------

V_pts=koornwinder_typeII(deg,pts_ok,-0.5);
dets=det(V_pts);

pts_leb=disk_wam(250);
V_leb= koornwinder_typeII(deg,pts_leb,-0.5);

lebs=norm(V_pts'\V_leb',1);
conds=condest(V_pts);

%-----------------------
% DISPLAYING CONSTANTS.
%-----------------------
if print_stats == 1
    fprintf('\n \n \t %% DEGREE: %3.0f',deg);
    fprintf('\n \t %% POINTS: %6.0f',size(pts,1));
    fprintf('\n \t %% LEBESGUE CONSTANT: %2.5e',lebs);
    fprintf('\n \t %% DETERMINANT: %2.5e',dets);
    fprintf('\n \t %% CONDITIONING: %2.5e',conds);
    fprintf('\n \t %% VANDERMONDE: KOORNWINDER II (-0.5).');
    if timing > 0
        minuti=floor(timing/60);
        secondi=floor(timing-minuti*60);
        fprintf('\n \t %% CPUTIME (MINUTES:SECONDS): %4.0f : %2.0f.\n',minuti,...
            secondi);
    else
        fprintf('\n');
    end
end

%-----------------------
% DISPLAYING POINTS.
%-----------------------
if print_stats == 1
    fprintf('\n \t pts=[');
    for kk=1:size(pts_ok,1)
        fprintf('\n \t %1.30e %1.30e',pts_ok(kk,1),pts_ok(kk,2));
    end
    fprintf('\n \t ]; \n ');

    if length(t) > 0
        fprintf('\n \t t=[');
        for kk=1:size(t,1)
            fprintf('\n \t %1.30e',t(kk));
        end
        fprintf('\n \t ]; \n ');

    end

end
